@@ -33,7 +33,6 @@ from config import Config, ConfigError, ConfigInputStream
 import slimta.system
 
 from .validation import ConfigValidation, ConfigValidationError
-from .celery import get_celery_app, get_celery_worker
 from .logging import setup_logging
 
 
@@ -93,9 +92,10 @@ class SlimtaState(object):
             config_file = os.path.expanduser(config_file)
             config_dir = os.path.abspath(os.path.dirname(config_file))
             config_base = os.path.basename(config_file)
-            with self._with_chdir(config_dir):
-                if os.path.exists(config_base):
-                    return Config(config_base), config_file
+            if os.path.isdir(config_dir):
+                with self._with_chdir(config_dir):
+                    if os.path.exists(config_base):
+                        return Config(config_base), config_file
         return None, None
 
     def load_config(self, argparser, args):
@@ -137,7 +137,9 @@ class SlimtaState(object):
 
     def daemonize(self):
         flag = self.cfg.process.get(self.program).get('daemon', False)
-        if flag and not self.args.attached:
+        if self.args.attached is None and flag:
+            slimta.system.daemonize()
+        elif not self.args.attached:
             slimta.system.daemonize()
 
     def setup_logging(self):
@@ -312,6 +314,7 @@ class SlimtaState(object):
 
     @property
     def celery(self):
+        from .celery import get_celery_app
         if not self._celery:
             self._celery = get_celery_app(self.cfg)
         return self._celery
@@ -379,6 +382,7 @@ class SlimtaState(object):
                 self._start_edge(name, options)
 
     def worker_loop(self):
+        from .celery import get_celery_worker
         try:
             with self._with_sighandlers():
                 with self._with_pid_file():
